@@ -114,6 +114,8 @@ def compute_telluric_molecfit_v1(config_in):
                                   input_data[obs]['e2ds_err'],
                                   observational_pams['wavelength_rescaling'])
 
+            preserve_flux = input_data[obs].get('absolute_flux', True)
+
             processed[obs]['rebin_ORF'] = \
             rebin_2d_to_1d(input_data[obs]['wave'],
                            input_data[obs]['step'],
@@ -121,6 +123,7 @@ def compute_telluric_molecfit_v1(config_in):
                            calib_data['blaze'],
                            processed['rebin']['wave'],
                            processed['rebin']['step'],
+                           preserve_flux=preserve_flux,
                            rv_shift=0.00)
 
             """ Molecfit analysis is skipped if the telluric computation has been computed already"""
@@ -136,6 +139,8 @@ def compute_telluric_molecfit_v1(config_in):
             fileout.close()
 
             """
+            preserve_flux = input_data[obs].get('absolute_flux', True)
+
             processed[obs]['rebin_SRF'] = \
             rebin_2d_to_1d(input_data[obs]['wave'],
                            input_data[obs]['step'],
@@ -143,6 +148,7 @@ def compute_telluric_molecfit_v1(config_in):
                            calib_data['blaze'],
                            processed['rebin']['wave'],
                            processed['rebin']['step'],
+                           preserve_flux=preserve_flux,
                            rv_shift = observational_pams[obs]['rv_shift_ORF2SRF'])
 
             fileout = open('./molecfit_'+night +'/'+obs+'_SRF_s1d.dat','w')
@@ -436,6 +442,8 @@ def compute_telluric_molecfit_v1(config_in):
             telluric_molecfit = np.genfromtxt('./molecfit_'+night +'/output/'+obs+'_ORF_s1d_TAC.dat', usecols=2)
             """ rebinning onto the e2ds wave scale"""
 
+            preserve_flux = input_data[obs].get('absolute_flux', True)
+
             telluric[obs]['spectrum'] = \
                 rebin_1d_to_2d(processed['rebin']['wave'],
                                processed['rebin']['step'],
